treewide: Get rid of CONFIG_AZALIA_MAX_CODECS

Get rid of Kconfig symbol introduced at commit 5d31dfa8
High Definition Audio Specification Revision 1.0a says, there
are 15 SDIWAKE bits.

Signed-off-by: Elyes Haouas <ehaouas@noos.fr>
Change-Id: Ib8b656daca52e21cb0c7120b208a2acdd88625e1
Reviewed-on: https://review.coreboot.org/c/coreboot/+/62202
Reviewed-by: Nico Huber <nico.h@gmx.de>
Reviewed-by: Angel Pons <th3fanbus@gmail.com>
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
diff --git a/src/device/azalia_device.c b/src/device/azalia_device.c
index e61e1dc..4ac585d 100644
--- a/src/device/azalia_device.c
+++ b/src/device/azalia_device.c
@@ -50,7 +50,6 @@
 static u16 codec_detect(u8 *base)
 {
 	struct stopwatch sw;
-	const u16 codec_mask = (1 << CONFIG_AZALIA_MAX_CODECS) - 1;
 	u16 reg16;
 
 	if (azalia_exit_reset(base) < 0)
@@ -61,9 +60,9 @@
 		write16(base + HDA_GCAP_REG, read16(base + HDA_GCAP_REG));
 	}
 
 	/* clear STATESTS bits (BAR + 0xe)[2:0] */
 	reg16 = read16(base + HDA_STATESTS_REG);
-	reg16 |= codec_mask;
+	reg16 |= 0x7fff;
 	write16(base + HDA_STATESTS_REG, reg16);
 
 	/* Wait for readback of register to
@@ -86,9 +85,9 @@
 	if (azalia_exit_reset(base) < 0)
 		goto no_codec;
 
 	/* Read in Codec location (BAR + 0xe)[2..0] */
 	reg16 = read16(base + HDA_STATESTS_REG);
-	reg16 &= codec_mask;
+	reg16 &= 0x7fff;
 	if (!reg16)
 		goto no_codec;
 
@@ -274,7 +273,7 @@
 {
 	int i;
 
-	for (i = CONFIG_AZALIA_MAX_CODECS - 1; i >= 0; i--) {
+	for (i = 14; i >= 0; i--) {
 		if (codec_mask & (1 << i))
 			azalia_codec_init(base, i, cim_verb_data, cim_verb_data_size);
 	}
@@ -61,9 +60,9 @@
 	}
 
-	/* clear STATESTS bits (BAR + 0xe)[2:0] */
+	/* clear STATESTS bits (BAR + 0x0e)[14:0] */
 	reg16 = read16(base + HDA_STATESTS_REG);
@@ -86,9 +85,9 @@
 		goto no_codec;
 
-	/* Read in Codec location (BAR + 0xe)[2..0] */
+	/* Read in Codec location (BAR + 0x0e)[14:0] */
 	reg16 = read16(base + HDA_STATESTS_REG);